@@ -601,8 +601,12 @@ hd_wm_application_new (const gchar *file)
 
       g_free (app_name);
     }
-  
-  app->priv->icon_name      = icon_name; 
+ 
+  if (icon_name) 
+    app->priv->icon_name = icon_name; 
+  else
+    app->priv->icon_name = g_strdup("qgn_list_gene_default_app");
+
   app->priv->service        = service;    
   app->priv->exec_name      = exec_name;
   app->priv->text_domain    = text_domain;
