@@ -63,6 +63,7 @@
 #define HD_HOME_BACKGROUND_VALUE_CROPPED        "Cropped"
 
 #define HD_ENV_MMC_MOUNTPOINT                   "MMC_MOUNTPOINT"
+#define HD_ENV_SECOND_MMC_MOUNTPOINT            "INTERNAL_MMC_MOUNTPOINT"
 #define HD_HOME_BACKGROUND_CACHE_DIR             ".background-cache"
 
 struct _HDHomeBackgroundPrivate {
@@ -361,7 +362,7 @@ hd_home_background_requires_caching (HDHomeBackground *background)
   gchar        *filename = NULL;
   const gchar  *mmc_mount_point;
   gchar        *mmc_mount_point_uri = NULL;
-  gboolean      on_internal_mmc = FALSE, on_external_fs = FALSE;
+  gboolean      on_first_mmc = FALSE, on_second_mmc = FALSE, on_external_fs = FALSE;
 
   g_object_get (background,
                 "filename", &filename,
@@ -373,25 +374,33 @@ hd_home_background_requires_caching (HDHomeBackground *background)
     return FALSE;
 
   mmc_mount_point = g_getenv (HD_ENV_MMC_MOUNTPOINT);
-  mmc_mount_point_uri = g_strdup_printf ("file://%s", mmc_mount_point);
+  if (mmc_mount_point)
+  {
+    mmc_mount_point_uri = g_strdup_printf ("file://%s", mmc_mount_point);
 
-  if (mmc_mount_point &&
-      (g_str_has_prefix (filename, mmc_mount_point) ||
-       g_str_has_prefix (filename, mmc_mount_point_uri)))
-    on_internal_mmc = TRUE;
+    if (g_str_has_prefix (filename, mmc_mount_point) ||
+        g_str_has_prefix (filename, mmc_mount_point_uri))
+      on_first_mmc = TRUE;
 
-  g_free (mmc_mount_point_uri);
+    g_free (mmc_mount_point_uri);
+  }
+
+  mmc_mount_point = g_getenv (HD_ENV_SECOND_MMC_MOUNTPOINT);
+  if (mmc_mount_point)
+  {
+    mmc_mount_point_uri = g_strdup_printf ("file://%s", mmc_mount_point);
+
+    if (g_str_has_prefix (filename, mmc_mount_point) ||
+        g_str_has_prefix (filename, mmc_mount_point_uri))
+      on_second_mmc = TRUE;
+
+    g_free (mmc_mount_point_uri);
+  }
 
   on_external_fs = filename[0] != G_DIR_SEPARATOR &&
       (!g_str_has_prefix (filename, "file://"));
 
-#ifdef DEBUG
-  g_debug ("filename %s requires caching: %i",
-           filename,
-           (on_internal_mmc || on_external_fs));
-#endif
-  
-  return (on_internal_mmc || on_external_fs);
+  return (on_first_mmc || on_second_mmc || on_external_fs);
 
 
 }
