@@ -573,39 +573,44 @@ refresh_app_button (HNAppSwitcher *app_switcher,
 
   gdk_window_get_position (panel->window, &panel_x, &panel_y);  
 
-  /* deal with urgency flags */
-  for (l = children; l != NULL; l = l->next)
+  if (!hd_wm_entry_info_is_hibernating (entry))
   {
-    HDWMEntryInfo *_info = HD_WM_ENTRY_INFO (l->data);	  
-	  
-    {	    
-      hd_wm_window_set_icon_geometry (HD_WM_WINDOW (l->data),	    
-	      		              GTK_WIDGET (app_button)->allocation.x + panel_x,
-				      GTK_WIDGET (app_button)->allocation.y + panel_y,
-				      GTK_WIDGET (app_button)->allocation.width,
-				      GTK_WIDGET (app_button)->allocation.height,
-				      TRUE);
-    }
-    /*
-     * If the entry is urgent and the ignore flag is not set, the button
-     * should blink
-     */
-    if (hd_wm_entry_info_is_urgent (_info) &&
-        !hd_wm_entry_info_get_ignore_urgent (_info))
+    /* deal with urgency flags */
+    for (l = children; l != NULL; l = l->next)
     {
-      hd_wm_debug("Found an urgent button");
-      urgent = TRUE;
+      HDWMEntryInfo *_info = HD_WM_ENTRY_INFO (l->data);	  
+
+      {	    
+        hd_wm_window_set_icon_geometry (HD_WM_WINDOW (l->data),	    
+                                        GTK_WIDGET (app_button)->allocation.x + panel_x,
+                                        GTK_WIDGET (app_button)->allocation.y + panel_y,
+                                        GTK_WIDGET (app_button)->allocation.width,
+                                        GTK_WIDGET (app_button)->allocation.height,
+                                        TRUE);
+      }
+      /*
+       * If the entry is urgent and the ignore flag is not set, the button
+       * should blink
+       */
+      if (hd_wm_entry_info_is_urgent (_info) &&
+          !hd_wm_entry_info_get_ignore_urgent (_info))
+      {
+        hd_wm_debug("Found an urgent button");
+        urgent = TRUE;
+      }
+
+      /*
+       * if the info is not urgent, we need to clear any leftover
+       * ignore_urgent flag
+       */
+      if(!hd_wm_entry_info_is_urgent (_info) &&
+         hd_wm_entry_info_get_ignore_urgent (_info))
+      {
+        hd_wm_entry_info_set_ignore_urgent (_info, FALSE);
+      }
     }
 
-   /*
-    * if the info is not urgent, we need to clear any leftover
-    * ignore_urgent flag
-    */
-    if(!hd_wm_entry_info_is_urgent (_info) &&
-       hd_wm_entry_info_get_ignore_urgent (_info))
-    {
-      hd_wm_entry_info_set_ignore_urgent (_info, FALSE);
-    }
+    hn_app_button_set_is_blinking (app_button, urgent);
   }
   
   /* bind the entry info to the widget, so that we can
@@ -620,7 +625,6 @@ refresh_app_button (HNAppSwitcher *app_switcher,
   hd_wm_debug ("buttons_group.size := %d",
 	  g_slist_length (priv->buttons_group));
 
-  hn_app_button_set_is_blinking (app_button, urgent);
 
   if (hd_wm_entry_info_is_active (entry))
   {
